#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 dhall-json
version:              1.7.12
visibility:           public
id:                   dhall-json-1.7.12-1XGxHfS3D3BBJuh383L0qH
key:                  dhall-json-1.7.12-1XGxHfS3D3BBJuh383L0qH
license:              BSD-3-Clause
copyright:            2017 Gabriella Gonzalez
maintainer:           GenuineGabriella@gmail.com
author:               Gabriella Gonzalez
synopsis:             Convert between Dhall and JSON or YAML
description:
    Use this package if you want to convert between Dhall expressions and JSON
    or YAML. You can use this package as a library or an executable:

    * See the "Dhall.JSON" or "Dhall.JSONToDhall" modules if you want to use
    this package as a library

    * Use the @dhall-to-json@, @dhall-to-yaml@, or @json-to-dhall@ programs from
    this package if you want an executable

    The "Dhall.JSON" and "Dhall.JSONToDhall" modules also contains instructions
    for how to use this package

category:             Compiler
abi:                  8b24655e66c49dfb2b1b6be72439cf21
exposed:              True
exposed-modules:
    Dhall.DhallToYaml.Main Dhall.JSON Dhall.JSON.Yaml Dhall.JSONToDhall

hidden-modules:       Dhall.JSON.Compat Dhall.JSON.Util
import-dirs:          /usr/lib/ghc-9.6.6/site-local/dhall-json-1.7.12
library-dirs:         /usr/lib/ghc-9.6.6/site-local/dhall-json-1.7.12
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/dhall-json-1.7.12
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/dhall-json
hs-libraries:         HSdhall-json-1.7.12-1XGxHfS3D3BBJuh383L0qH
depends:
    aeson-2.2.1.0-CAI92PkToAUJ8bQ51mPxny
    aeson-pretty-0.8.10-2A0qmC3PrFRBo1atFn5LHb
    aeson-yaml-1.1.0.1-9fRCYY7riyNJlQJOcOFajZ base-4.18.2.1
    bytestring-0.11.5.3 containers-0.6.7
    dhall-1.42.3-EujrYJq0GmQGDJYZCSnes3 exceptions-0.10.7
    filepath-1.4.300.1 lens-family-core-2.1.3-ATkyQy7CaRL9XkLMxregni
    optparse-applicative-0.18.1.0-8x9tqfysnGJFgxd4Oy1ewE
    prettyprinter-1.7.1-GiZuScg817SGeNuRUeFCVg
    scientific-0.3.8.1-Ft3WVJQfxgFDXI2EBhkoPK text-2.0.2
    unordered-containers-0.2.20.1-BfuATd0ZFSGCCCUDlG7vl5
    vector-0.13.2.0-rptRAMabEKKDkHNfCXlHC

haddock-interfaces:   /usr/share/doc/dhall-json/html/dhall-json.haddock
haddock-html:         /usr/share/doc/dhall-json/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

